@@ -197,13 +197,15 @@ int db_key::exportFlags(const QModelIndex &index) const
 		disable_flags |= F_PVK;
 #ifdef EVP_PKEY_ED25519
 	if (keytype == EVP_PKEY_ED25519)
-		disable_flags |= F_CRYPT;
+		disable_flags |= F_TRADITION;
 #endif
 	if (!key->SSH2_compatible())
 		disable_flags |= F_SSH2;
 
 	if (key->isPubKey() || key->isToken())
 		disable_flags |= F_PRIVATE;
+	if (keytype != EVP_PKEY_RSA && key->getJWKcrv().isEmpty())
+		disable_flags |= F_JWK;
 
 	return disable_flags;
 }
@@ -232,14 +234,14 @@ void db_key::exportItem(const QModelIndex &index, const pki_export *xport,
 		key->writePublic(file, true);
 	else if (privkey && xport->match_all(F_PKCS8))
 		privkey->writePKCS8(file, algo, pwCallback, true);
-	else if (xport->match_all(F_SSH2 | F_PRIVATE))
-		key->writeSSH2private(file, pwCallback);
+	else if (privkey && xport->match_all(F_SSH2 | F_PRIVATE))
+		privkey->writeSSH2private(file);
 	else if (xport->match_all(F_SSH2))
 		key->writeSSH2public(file);
 	else if (privkey && xport->match_all(F_PVK))
-		privkey->writePVKprivate(file, pwCallback);
+		privkey->writePVKprivate(file);
 	else
-		throw errorEx(tr("Internal error"));
+		db_base::exportItem(index, xport, file);
 }
 
 void db_key::updateKeyEncryptionScheme()
