@@ -13,7 +13,10 @@
 
 const QList<int> digest::all_digests(
 	{ NID_md5, NID_ripemd160, NID_sha1,
-	  NID_sha224, NID_sha256, NID_sha384, NID_sha512
+	  NID_sha224, NID_sha256, NID_sha384, NID_sha512,
+#ifndef LIBRESSL_VERSION_NUMBER
+	  NID_sha3_224, NID_sha3_256, NID_sha3_384, NID_sha3_512,
+#endif
 });
 
 int digest::default_md(NID_sha256);
