@@ -13,18 +13,20 @@
 
 class digest
 {
-    private:
+  private:
 	static int default_md;
-	int md_nid;
+	int md_nid{ NID_sha256 };
 
-    public:
+  public:
 	static const QList<int> all_digests;
 
+	digest() { };
 	digest(int nid);
 	digest(const EVP_MD *md);
 	digest(const QString &name);
-    digest(const digest &d) = default;
-    digest& operator=(const digest &d) = default;
+	digest(const digest &d) = default;
+	digest& operator=(const digest &d) = default;
+	void adjust(QList<int> nids);
 
 	bool isInsecure() const;
 	const EVP_MD *MD() const;
