@@ -117,6 +117,7 @@ static QString registryInstallDir()
 int portable_app()
 {
 	static int portable = -1;
+	qDebug() << "portable" << portable;
 	QString f1, f2;
 	if (portable == -1) {
 #if defined(Q_OS_WIN32)
@@ -221,6 +222,9 @@ const QString getDocDir()
 	QStringList docs;
 #ifdef DOCDIR
 	docs << QString(DOCDIR);
+#endif
+#ifdef INSTALL_DATA_PREFIX
+	docs << QString(INSTALL_DATA_PREFIX);
 #endif
 	docs += QStandardPaths::standardLocations(QStandardPaths::AppDataLocation);
 	foreach (docdir, docs) {
@@ -260,9 +264,21 @@ const QString getUserSettingsDir()
 
 const QString getI18nDir()
 {
-	QString qm = QStandardPaths::locate(QStandardPaths::AppDataLocation,
-		I18N_DIR "xca_de.qm");
-	return QFileInfo(qm).path();
+	static QString qm;
+	if (!qm.isEmpty())
+		return qm;
+#ifdef INSTALL_DATA_PREFIX
+	if (QFileInfo::exists(INSTALL_DATA_PREFIX "/xca_de.qm"))
+		qm = INSTALL_DATA_PREFIX "/xca_de.qm";
+#endif
+	if (qm.isEmpty())
+		qm = QStandardPaths::locate(QStandardPaths::AppDataLocation,
+			I18N_DIR "xca_de.qm");
+	if (qm.isEmpty())
+		qm = QCoreApplication::applicationDirPath() + "/xca_de.qm";
+	qm = QFileInfo(qm).path();
+	qDebug() << "QM" << qm;
+	return qm;
 }
 
 void migrateOldPaths()
@@ -334,9 +350,8 @@ QString hostId()
 
 #else
 	QString mach_id;
-	QStringList dirs; dirs <<
-			"/etc" << "/var/lib/dbus" << "/var/db/dbus";
-	foreach(QString dir, dirs) {
+	const QStringList dirs = { "/etc", "/var/lib/dbus", "/var/db/dbus" };
+	for (const QString &dir : dirs) {
 		QFile file(dir + "/machine-id");
 		if (file.open(QIODevice::ReadOnly)) {
 			QTextStream in(&file);
@@ -369,5 +384,9 @@ QString fingerprint(const QByteArray &data, const EVP_MD *type)
 
 void update_workingdir(const QString &file)
 {
-	Settings["workingdir"] = QFileInfo(file).absolutePath();
+	QFileInfo fi(file);
+	if (fi.isDir())
+		Settings["workingdir"] = fi.absoluteFilePath();
+	else
+		Settings["workingdir"] = fi.absolutePath();
 }
