@@ -41,20 +41,30 @@ void waitcursor(int start, int line)
 }
 
 pkcs11_lib_list pkcs11::libraries;
+int pkcs11::pctr;
 
 pkcs11::pkcs11()
 {
 	session = CK_INVALID_HANDLE;
 	p11obj = CK_INVALID_HANDLE;
+	qDebug() << "PKCS11 Counter"<< ++pctr;
 }
 
 pkcs11::~pkcs11()
 {
-	if (session != CK_INVALID_HANDLE && p11slot.p11()) {
+	try { closeSession(p11slot); } catch ( ... ) { }
+	qDebug() << "PKCS11 Counter"<< --pctr;
+}
+
+void pkcs11::closeSession(const slotid &slot)
+{
+	if (session != CK_INVALID_HANDLE && slot.p11()) {
 		CK_RV rv;
 		CALL_P11_C(p11slot.lib, C_CloseSession, session);
-		(void)rv;
+		if (rv != CKR_OK)
+			pk11error(slot, "C_CloseSession", rv);
 	}
+	session = CK_INVALID_HANDLE;
 }
 
 void pkcs11::startSession(const slotid &slot, bool rw)
@@ -62,12 +72,8 @@ void pkcs11::startSession(const slotid &slot, bool rw)
 	CK_RV rv;
 	unsigned long flags = CKF_SERIAL_SESSION | (rw ? CKF_RW_SESSION : 0);
 
-	if (session != CK_INVALID_HANDLE) {
-		CALL_P11_C(slot.lib, C_CloseSession, session);
-		session = CK_INVALID_HANDLE;
-		if (rv != CKR_OK)
-			pk11error(slot, "C_CloseSession", rv);
-	}
+	closeSession(slot);
+
 	CALL_P11_C(slot.lib, C_OpenSession,
 			slot.id, flags, NULL, NULL, &session);
 	if (rv != CKR_OK)
@@ -215,7 +221,13 @@ static QDialog *newPinPadBox()
 	return box;
 }
 
-QString pkcs11::tokenLogin(QString name, bool so, bool force)
+bool pkcs11::tokenLoginForModification()
+{
+	 tkInfo ti = tokenInfo();
+	 return !tokenLogin(ti.label(), ti.need_SO_for_object_mod()).isNull();
+}
+
+QString pkcs11::tokenLogin(const QString &name, bool so, bool force)
 {
 	Passwd pin;
 	bool need_login;
@@ -231,7 +243,7 @@ QString pkcs11::tokenLogin(QString name, bool so, bool force)
 		if (!need_login)
 			logout();
 		if (tokenInfo().protAuthPath()) {
-			pin.clear();
+			pin = ""; // Indicate success
 			QDialog *pinpadbox = newPinPadBox();
 			pinpadbox->show();
 			pinPadLoginThread ppt(this, so);
@@ -246,8 +258,8 @@ QString pkcs11::tokenLogin(QString name, bool so, bool force)
 		} else {
 			if (PwDialogCore::execute(&p, &pin, false) != 1)
 				return QString();
+			login(pin.constUchar(), pin.size(), so);
 		}
-		login(pin.constUchar(), pin.size(), so);
 	} else {
 		return QString("");
 	}
@@ -348,13 +360,11 @@ void pkcs11::initPin(const slotid &slot)
 {
 	Passwd newPin, pinp;
 	int ret = 1;
-	QString pin;
 
 	startSession(slot, true);
 	tkInfo ti = tokenInfo();
 
-	pin = tokenLogin(ti.label(), true, false);
-	if (pin.isNull())
+	if (tokenLogin(ti.label(), true, false).isNull())
 		return;
 
 	pass_info p(XCA_TITLE, newPinTxt.arg(ti.label()) + "\n" + ti.pinInfo());
@@ -389,7 +399,7 @@ void pkcs11::initToken(const slotid &slot, unsigned char *pin, int pinlen,
 		pk11error(slot, "C_InitToken", rv);
 }
 
-tkInfo pkcs11::tokenInfo(const slotid &slot)
+tkInfo pkcs11::tokenInfo(const slotid &slot) const
 {
 	tkInfo ti;
 	CK_RV rv = tokenInfo(slot, &ti);
@@ -400,7 +410,7 @@ tkInfo pkcs11::tokenInfo(const slotid &slot)
 	return ti;
 }
 
-CK_RV pkcs11::tokenInfo(const slotid &slot, tkInfo *tkinfo)
+CK_RV pkcs11::tokenInfo(const slotid &slot, tkInfo *tkinfo) const
 {
 	CK_TOKEN_INFO token_info;
 	CK_RV rv;
@@ -452,7 +462,7 @@ int pkcs11::deleteObjects(QList<CK_OBJECT_HANDLE> objects)
 }
 
 #define ID_LEN 8
-pk11_attr_data pkcs11::findUniqueID(unsigned long oclass)
+pk11_attr_data pkcs11::findUniqueID(unsigned long oclass) const
 {
 	pk11_attr_data id(CKA_ID);
 	pk11_attr_ulong class_att(CKA_CLASS, oclass);
@@ -470,20 +480,19 @@ pk11_attr_data pkcs11::findUniqueID(unsigned long oclass)
 }
 
 pk11_attr_data pkcs11::generateKey(QString name, unsigned long mech,
-				unsigned long bits, int nid)
+				unsigned long bits, int nid, const pk11_attr_data &id)
 {
 #ifdef OPENSSL_NO_EC
 	(void)nid;
 #endif
+	tkInfo ti = tokenInfo();
 	CK_RV rv;
 	CK_OBJECT_HANDLE pubkey, privkey, dsa_param_obj;
 	pk11_attlist priv_atts, pub_atts, dsa_param;
 	CK_MECHANISM mechanism = {mech, NULL_PTR, 0};
 	pk11_attr_data label(CKA_LABEL, name.toUtf8());
 
-	pk11_attr_data new_id = findUniqueID(CKO_PUBLIC_KEY);
-
-	pub_atts << label << new_id <<
+	pub_atts << label << id <<
 		pk11_attr_ulong(CKA_CLASS, CKO_PUBLIC_KEY) <<
 		pk11_attr_bool(CKA_TOKEN, true) <<
 		pk11_attr_bool(CKA_PRIVATE, false) <<
@@ -491,7 +500,7 @@ pk11_attr_data pkcs11::generateKey(QString name, unsigned long mech,
 		pk11_attr_bool(CKA_VERIFY, true) <<
 		pk11_attr_bool(CKA_WRAP, true);
 
-	priv_atts << label << new_id <<
+	priv_atts << label << id <<
 		pk11_attr_ulong(CKA_CLASS, CKO_PRIVATE_KEY) <<
 		pk11_attr_bool(CKA_TOKEN, true) <<
 		pk11_attr_bool(CKA_PRIVATE, true) <<
@@ -500,8 +509,6 @@ pk11_attr_data pkcs11::generateKey(QString name, unsigned long mech,
 		pk11_attr_bool(CKA_SIGN, true) <<
 		pk11_attr_bool(CKA_UNWRAP, true);
 
-	QString mID = tokenInfo().manufacturerID();
-
 	switch (mech) {
 	case CKM_RSA_PKCS_KEY_PAIR_GEN:
 		pub_atts <<
@@ -512,17 +519,10 @@ pk11_attr_data pkcs11::generateKey(QString name, unsigned long mech,
 		//DSA: Spec Page 191 (175) C_GenerateKey
 		CK_MECHANISM mechanism = {CKM_DSA_PARAMETER_GEN, NULL_PTR, 0};
 
-		// nCipher Attributes
-		// as on 10/26/2015 - Thales' PKCS11 provider has
-		// issue to generate Domain Parameters
-		bool token = true;
-		if (mID == "nCipher Corp. Ltd")
-			token = false;
-
 		dsa_param << label <<
 			pk11_attr_ulong(CKA_CLASS, CKO_DOMAIN_PARAMETERS) <<
 			pk11_attr_ulong(CKA_KEY_TYPE, CKK_DSA) <<
-			pk11_attr_bool(CKA_TOKEN, token) <<
+			pk11_attr_bool(CKA_TOKEN, !ti.set_token_attr_false_dsa_param()) <<
 			pk11_attr_bool(CKA_PRIVATE, false) <<
 			pk11_attr_ulong(CKA_PRIME_BITS, bits);
 		p11slot.isValid();
@@ -547,13 +547,9 @@ pk11_attr_data pkcs11::generateKey(QString name, unsigned long mech,
 
 		EC_GROUP *group = EC_GROUP_new_by_curve_name(nid);
 
-		EC_GROUP_set_asn1_flag(group, info.flags & CKF_EC_NAMEDCURVE ?
-			OPENSSL_EC_NAMED_CURVE : 0);
-
-		// Workaround for "www.CardContact.de" bug
-		if (mID == "www.CardContact.de") {
-			EC_GROUP_set_asn1_flag(group, OPENSSL_EC_NAMED_CURVE);
-		}
+		EC_GROUP_set_asn1_flag(group,
+			((info.flags & CKF_EC_NAMEDCURVE) || ti.force_keygen_named_curve()) ?
+				OPENSSL_EC_NAMED_CURVE : 0);
 
 		priv_atts << pk11_attr_bool(CKA_DERIVE, false);
 		pub_atts << pk11_attr_data(CKA_EC_PARAMS,
@@ -573,10 +569,10 @@ pk11_attr_data pkcs11::generateKey(QString name, unsigned long mech,
 	if (rv != CKR_OK) {
 		pk11error("C_GenerateKeyPair", rv);
 	}
-	return new_id;
+	return id;
 }
 
-QList<CK_OBJECT_HANDLE> pkcs11::objectList(pk11_attlist &atts)
+QList<CK_OBJECT_HANDLE> pkcs11::objectList(pk11_attlist &atts) const
 {
 	CK_RV rv;
 	CK_OBJECT_HANDLE objects[256];
