@@ -5,6 +5,7 @@
  * All rights reserved.
  */
 
+#include <QJsonDocument>
 
 #include "pki_key.h"
 #include "pki_x509super.h"
@@ -90,39 +91,6 @@ QByteArray pki_key::i2d() const
 	return i2d_bytearray(I2D_VOID(i2d_PUBKEY), key);
 }
 
-void pki_key::write_SSH2_ed25519_private(BIO *b,
-			 const EVP_PKEY *pkey, const EVP_CIPHER *enc) const
-{
-	(void)enc;
-#ifndef OPENSSL_NO_EC
-	static const char data0001[] = { 0, 0, 0, 1};
-	char buf_nonce[8];
-	QByteArray data, priv, pubfull;
-
-	pubfull = SSH2publicQByteArray(true);
-	RAND_bytes((unsigned char*)buf_nonce, sizeof buf_nonce);
-	priv.append(buf_nonce, sizeof buf_nonce);
-	priv += pubfull;
-	ssh_key_QBA2data(ed25519PrivKey(pkey) + ed25519PubKey(), &priv);
-
-	data = "openssh-key-v1";
-	data.append('\0');
-	ssh_key_QBA2data("none", &data); // enc-alg
-	ssh_key_QBA2data("none", &data); // KDF name
-	ssh_key_QBA2data("", &data); // KDF data
-	data.append(data0001, sizeof data0001);
-	ssh_key_QBA2data(pubfull, &data);
-	ssh_key_QBA2data(priv, &data);
-
-	PEM_write_bio(b, PEM_STRING_OPENSSH_KEY, (char*)"",
-		(unsigned char*)(data.data()), data.size());
-	pki_openssl_error();
-#else
-	(void)b;
-	(void)pkey;
-#endif
-}
-
 bool pki_key::pem(BioByteArray &b)
 {
 	return pem(b, pki_export::by_id(Settings["KeyFormat"]));
@@ -140,21 +108,66 @@ bool pki_key::pem(BioByteArray &b, const pki_export *xport)
 	return true;
 }
 
-void pki_key::writeSSH2private(XFile &file, pem_password_cb *cb) const
+QString pki_key::getJWKcrv() const
 {
-	(void)cb;
-//	pass_info p(XCA_TITLE, tr("Please enter the password protecting the SSH2 private key '%1'").arg(getIntName()));
-
-	EVP_PKEY *pkey = decryptKey();
-	if (!pkey) {
-		pki_openssl_error();
-		return;
+	const char *name = nullptr;
+#ifndef OPENSSL_NO_EC
+	if (getKeyType() == EVP_PKEY_EC) {
+		const EC_KEY *ec = EVP_PKEY_get0_EC_KEY(key);
+		int nid = EC_GROUP_get_curve_name(EC_KEY_get0_group(ec));
+		switch (nid) {
+		case NID_X9_62_prime256v1:
+		case NID_secp384r1:
+		case NID_secp521r1:
+		case NID_secp256k1:
+			name = EC_curve_nid2nist(nid);
+			if (!name)
+				name = OBJ_nid2sn(nid);
+		}
+		qDebug() << name << OBJ_nid2sn(nid) << nid;
 	}
-	BioByteArray b;
-	write_SSH2_ed25519_private(b, pkey, NULL);
-	file.write(b);
+#endif
+	return QString(name);
 }
 
+void pki_key::fillJWK(QJsonObject &json, const pki_export *) const
+{
+	json["kid"] = getIntName();
+
+	switch (getKeyType()) {
+	case EVP_PKEY_RSA: {
+		const RSA *rsa = EVP_PKEY_get0_RSA(key);
+		Q_CHECK_PTR(rsa);
+		const BIGNUM *n, *e;
+		RSA_get0_key(rsa, &n, &e, NULL);
+		json["n"] = base64UrlEncode(n);
+		json["e"] = base64UrlEncode(e);
+		json["kty"] = "RSA";
+		break;
+		}
+#ifndef OPENSSL_NO_EC
+	case EVP_PKEY_EC: {
+		const EC_KEY *ec = EVP_PKEY_get0_EC_KEY(key);
+		BIGNUM *x = BN_new(), *y = BN_new();
+		Q_CHECK_PTR(x);
+		Q_CHECK_PTR(y);
+		if (EC_POINT_get_affine_coordinates_GFp(EC_KEY_get0_group(ec),
+			EC_KEY_get0_public_key(ec), x, y, NULL))
+		{
+			int bits = EVP_PKEY_bits(key);
+			json["x"] = base64UrlEncode(x, bits);
+			json["y"] = base64UrlEncode(y, bits);
+			json["kty"] = "EC";
+			json["crv"] = getJWKcrv();
+		}
+		BN_free(x);
+		BN_free(y);
+		break;
+		}
+#endif
+	}
+};
+
 QString pki_key::length() const
 {
 	bool dsa_unset = false;
@@ -186,35 +199,33 @@ QString pki_key::getTypeString() const
 	return getKeyTypeString();
 }
 
-QString pki_key::getMsg(msg_type msg) const
+QString pki_key::getMsg(msg_type msg, int n) const
 {
 	/*
 	 * We do not construct english sentences (just a little bit)
 	 * from fragments to allow proper translations.
 	 * The drawback are all the slightly different duplicated messages
-	 *
-	 * %1 will be replaced by "RSA", "DSA", "EC"
-	 * %2 is the internal name of the key
 	 */
 	QString ktype = getTypeString();
 	if (isPubKey()) {
 		switch (msg) {
-		case msg_import: return tr("Successfully imported the %1 public key '%2'").arg(ktype);
-		case msg_delete: return tr("Delete the %1 public key '%2'?").arg(ktype);
+		case msg_import: return tr("Successfully imported the %1 public key '%2'",
+				"%1 will be replaced by 'RSA', 'DSA', 'EC'. %2 is the internal name of the key").arg(ktype);
+		case msg_delete: return tr("Delete the %n %1 public key(s) '%2'?",
+				"%1 will be replaced by 'RSA', 'DSA', 'EC'. %2 is/are the internal name(s) of the key(s)", n).arg(ktype);
 		default: break;
 		}
 	} else {
 		switch (msg) {
-		case msg_import: return tr("Successfully imported the %1 private key '%2'").arg(ktype);
-		case msg_delete: return tr("Delete the %1 private key '%2'?").arg(ktype);
-		case msg_create: return tr("Successfully created the %1 private key '%2'").arg(ktype);
+		case msg_import: return tr("Successfully imported the %1 private key '%2'",
+				"%1 will be replaced by 'RSA', 'DSA', 'EC'. %2 is the internal name of the key").arg(ktype);
+		case msg_delete: return tr("Delete the %n %1 private key(s) '%2'?",
+				"%1 will be replaced by 'RSA', 'DSA', 'EC'. %2 is/are the internal name(s) of the key(s)", n).arg(ktype);
+		case msg_create: return tr("Successfully created the %1 private key '%2'",
+				"%1 will be replaced by 'RSA', 'DSA', 'EC'. %2 is the internal name of the key").arg(ktype);
 		default: break;
 		}
 	}
-	if (msg == msg_delete_multi) {
-		/* %1: Number of keys; %2: list of keynames */
-		return tr("Delete the %1 keys: %2?");
-	}
 	return pki_base::getMsg(msg);
 }
 
@@ -378,19 +389,25 @@ QByteArray pki_key::ed25519PrivKey(const EVP_PKEY *) const
 QList<int> pki_key::possibleHashNids()
 {
 	QList<int> nids;
+	QList<int> allSha2 = { NID_sha224, NID_sha256, NID_sha384, NID_sha512 };
+#ifndef LIBRESSL_VERSION_NUMBER
+	QList<int> allSha3 = { NID_sha3_224, NID_sha3_256, NID_sha3_384, NID_sha3_512 };
+#else
+	QList<int> allSha3;
+#endif
 
 	switch (EVP_PKEY_type(getKeyType())) {
 		case EVP_PKEY_RSA:
-			nids << NID_md5 << NID_ripemd160 << NID_sha1 << NID_sha224 << NID_sha256 <<
-				NID_sha384 << NID_sha512;
+			nids << NID_md5 << NID_ripemd160 << NID_sha1;
+			nids += allSha2 + allSha3;
 			break;
 		case EVP_PKEY_DSA:
-			nids << NID_sha1 << NID_sha256;
+			nids << NID_sha1 << NID_sha224 << NID_sha256;
 			break;
 #ifndef OPENSSL_NO_EC
 		case EVP_PKEY_EC:
-			nids << NID_sha1 << NID_sha224 << NID_sha256 <<
-				NID_sha384 << NID_sha512;
+			nids << NID_sha1;
+			nids += allSha2 + allSha3;
 			break;
 #ifdef EVP_PKEY_ED25519
 		case EVP_PKEY_ED25519:
@@ -428,36 +445,13 @@ void pki_key::writePublic(XFile &file, bool pem) const
 	file.write(b);
 }
 
-QString pki_key::BNoneLine(BIGNUM *bn) const
-{
-	QString x;
-	if (bn) {
-		char *hex = BN_bn2hex(bn);
-		x = hex;
-		OPENSSL_free(hex);
-		pki_openssl_error();
-	}
-	return x;
-}
-
 QString pki_key::BN2QString(const BIGNUM *bn) const
 {
-	if (bn == NULL)
-		return "--";
-	QString x="";
-	char zs[10];
-	int j, size = BN_num_bytes(bn);
-	unsigned char *buf = (unsigned char *)OPENSSL_malloc(size);
-	Q_CHECK_PTR(buf);
-	BN_bn2bin(bn, buf);
-	for (j = 0; j< size; j++) {
-		snprintf(zs, sizeof zs, "%02X%c",buf[j], ((j+1)%16 == 0) ? '\n' :
-				j<size-1 ? ':' : ' ');
-		x += zs;
-	}
-	OPENSSL_free(buf);
-	pki_openssl_error();
-	return x;
+	QByteArray hex, ba = BioByteArray(bn);
+	for(int i = 0; i<ba.size(); i += 16)
+		hex += ba.mid(i, 16).toHex(':') + '\n';
+	hex.chop(1);
+	return QString::fromLatin1(hex);
 }
 
 QVariant pki_key::column_data(const dbheader *hd) const
@@ -698,13 +692,7 @@ void pki_key::ssh_key_QBA2data(const QByteArray &ba, QByteArray *data) const
 
 void pki_key::ssh_key_bn2data(const BIGNUM *bn, QByteArray *data) const
 {
-	QByteArray big;
-	big.resize(BN_num_bytes(bn));
-	BN_bn2bin(bn, (unsigned char *)big.data());
-	pki_openssl_error();
-	if ((unsigned char)big[0] >= 0x80)
-		big.prepend('\0');
-	ssh_key_QBA2data(big, data);
+	ssh_key_QBA2data(BioByteArray(bn), data);
 }
 
 bool pki_key::SSH2_compatible() const
