@@ -28,10 +28,12 @@ class encAlgo
 	encAlgo& operator=(const encAlgo &d) = default;
 
 	QString name() const;
+	QString displayName() const;
 	int getEncAlgoNid() const;
 	bool legacy() const
 	{
-		return encAlgo_nid == NID_pbe_WithSHA1And3_Key_TripleDES_CBC;
+		return encAlgo_nid == NID_pbe_WithSHA1And3_Key_TripleDES_CBC ||
+			   encAlgo_nid == NID_pbe_WithSHA1And40BitRC2_CBC;
 	}
 	static void setDefault(const QString &def);
 	static const encAlgo getDefault();
