@@ -19,6 +19,7 @@
 #include "XcaWarningCore.h"
 
 #include <QThread>
+#include <QInputDialog>
 
 void pki_scard::init(void)
 {
@@ -33,7 +34,7 @@ pki_scard::pki_scard(const QString &name)
 	init();
 }
 
-QString pki_scard::getMsg(msg_type msg) const
+QString pki_scard::getMsg(msg_type msg, int n) const
 {
 	/*
 	 * We do not construct english sentences from fragments
@@ -43,10 +44,8 @@ QString pki_scard::getMsg(msg_type msg) const
 	 */
 	switch (msg) {
 	case msg_import: return tr("Successfully imported the token key '%1'");
-	case msg_delete: return tr("Delete the token key '%1'?");
+	case msg_delete: return tr("Delete the %n token key(s): '%1'?", "", n);
 	case msg_create: return tr("Successfully created the token key '%1'");
-	/* %1: Number of ktemplates; %2: list of templatenames */
-	case msg_delete_multi: return tr("Delete the %1 keys: %2?");
 	}
 	return pki_base::getMsg(msg);
 }
@@ -377,7 +376,7 @@ void pki_scard::deleteFromToken(const slotid &slot)
 			arg(getIntName()).arg(ti.label()).arg(ti.serial())))
 		return;
 
-	if (p11.tokenLogin(card_label, false).isNull())
+	if (!p11.tokenLoginForModification())
 		return;
 
 	pk11_attlist atts = objectAttributes(true);
@@ -395,7 +394,7 @@ int pki_scard::renameOnToken(const slotid &slot, const QString &name)
 	p11.startSession(slot, true);
 	QList<CK_OBJECT_HANDLE> objs;
 
-	if (p11.tokenLogin(card_label, false).isNull())
+	if (!p11.tokenLoginForModification())
 		return 0;
 	pk11_attr_data label(CKA_LABEL, name.toUtf8());
 
@@ -450,7 +449,7 @@ void pki_scard::store_token(const slotid &slot, EVP_PKEY *pkey)
 		load_token(p11, objs[0]);
 		return;
 	}
-	pk11_attr_data new_id = p11.findUniqueID(CKO_PUBLIC_KEY);
+	pk11_attr_data new_id = select_id(p11);
 
 	pub_atts << new_id <<
 		pk11_attr_bool(CKA_TOKEN, true) <<
@@ -529,12 +528,14 @@ void pki_scard::store_token(const slotid &slot, EVP_PKEY *pkey)
 
 	}
 
-
-	tkInfo ti = p11.tokenInfo();
-	if (p11.tokenLogin(ti.label(), false).isNull())
+	if (!p11.tokenLoginForModification())
 		throw errorEx(tr("PIN input aborted"));
 
-	p11.createObject(pub_atts);
+	try {
+		p11.createObject(pub_atts);
+	} catch (errorEx &e) {
+		XCA_ERROR(e);
+	}
 	p11.createObject(priv_atts);
 
 	pub_atts.reset();
@@ -652,25 +653,50 @@ class keygenThread: public QThread
 {
 public:
 	errorEx err;
-	pk11_attr_data id;
 	const keyjob task;
 	QString name;
 	pkcs11 *p11;
+	pk11_attr_data id;
 
-	keygenThread(const keyjob &t, const QString &n, pkcs11 *_p11)
-		: QThread(), task(t), name(n), p11(_p11) { }
+	keygenThread(const keyjob &t, const QString &n, pkcs11 *_p11,
+				const pk11_attr_data &_id)
+		: QThread(), task(t), name(n), p11(_p11), id(_id) { }
 
 	void run()
 	{
 		try {
 			id = p11->generateKey(name, task.ktype.mech, task.size,
-						task.ec_nid);
+						task.ec_nid, id);
 		} catch (errorEx &e) {
 			err = e;
 		}
 	}
 };
 
+pk11_attr_data pki_scard::select_id(const pkcs11 &p11) const
+{
+	tkInfo ti = p11.tokenInfo();
+	pk11_attr_data new_id(CKA_ID);
+
+	QList<QStringList> fixed_ids = ti.fixed_ids();
+	if (fixed_ids.size() > 0) {
+		QMap<QString, unsigned long> map;
+		QStringList items;
+		for (QStringList item : fixed_ids) {
+			items << item[0];
+			map[item[0]] = item[1].toULong();
+		}
+		QString idname = QInputDialog::getItem(nullptr, XCA_TITLE,
+			tr("Select Slot of %1").arg(ti.model()),
+			items, 0, false);
+		if (map.contains(idname))
+			new_id.setULong(map[idname]);
+	} else {
+		new_id = p11.findUniqueID(CKO_PUBLIC_KEY);
+	}
+	return new_id;
+}
+
 void pki_scard::generate(const keyjob &task)
 {
 	pk11_attlist atts;
@@ -678,13 +704,14 @@ void pki_scard::generate(const keyjob &task)
 	pkcs11 p11;
 	p11.startSession(task.slot, true);
 	p11.getRandom();
-	tkInfo ti = p11.tokenInfo();
 
-	if (p11.tokenLogin(ti.label(), false).isNull())
+	pk11_attr_data new_id = select_id(p11);
+
+	if (!p11.tokenLoginForModification())
 		return;
 
 	XcaProgress progress;
-	keygenThread kt(task, getIntName(), &p11);
+	keygenThread kt(task, getIntName(), &p11, new_id);
 	kt.start();
 	while (!kt.wait(20)) {
 		progress.increment();
@@ -715,15 +742,14 @@ QString pki_scard::getTypeString(void) const
 EVP_PKEY *pki_scard::decryptKey() const
 {
 	slotid slot_id;
-	QString pin, key_id;
+	QString key_id;
 
 	if (!prepare_card(&slot_id))
 		throw errorEx(tr("Failed to find the key on the token"));
 
 	pkcs11 *p11 = new pkcs11();
 	p11->startSession(slot_id);
-	pin = p11->tokenLogin(card_label, false);
-	if (pin.isNull()) {
+	if (p11->tokenLogin(card_label, false).isNull()) {
 		delete p11;
 		throw errorEx(tr("Invalid Pin for the token"));
 	}
