@@ -17,6 +17,11 @@
 #include "exception.h"
 #include "pass_info.h"
 
+#include <openssl/rand.h>
+#include <openssl/err.h>
+#include <openssl/x509_vfy.h>
+#include <openssl/x509v3.h>
+
 pki_x509::pki_x509(X509 *c)
 	:pki_x509super(), cert(c)
 {
@@ -47,7 +52,7 @@ pki_x509::pki_x509(const QString &name)
 	pki_openssl_error();
 }
 
-QString pki_x509::getMsg(msg_type msg) const
+QString pki_x509::getMsg(msg_type msg, int n) const
 {
 	/*
 	 * We do not construct english sentences from fragments
@@ -58,10 +63,8 @@ QString pki_x509::getMsg(msg_type msg) const
 	 */
 	switch (msg) {
 	case msg_import: return tr("Successfully imported the certificate '%1'");
-	case msg_delete: return tr("Delete the certificate '%1'?");
+	case msg_delete: return tr("Delete the %n certificate(s): '%1'?", "", n);
 	case msg_create: return tr("Successfully created the certificate '%1'");
-	/* %1: Number of certs; %2: list of cert names */
-	case msg_delete_multi: return tr("Delete the %1 certificates: %2?");
 	}
 	return pki_base::getMsg(msg);
 }
@@ -143,6 +146,7 @@ QSqlError pki_x509::deleteSqlData()
 		<< "UPDATE crls SET issuer=NULL WHERE issuer=?"
 		<< "UPDATE certs SET issuer=NULL WHERE issuer=?"
 		<< "DELETE FROM revocations WHERE caId=?"
+		<< "DELETE FROM takeys WHERE item=?"
 		;
 	foreach(QString task, tasks) {
 		SQL_PREPARE(q, task);
@@ -188,7 +192,7 @@ pki_x509 *pki_x509::findIssuer()
 	q.exec();
 	while (q.next()) {
 		pki_x509 *an_issuer = Store.lookupPki<pki_x509>(q.value(0));
-		qDebug() << "Possibvle Issuer of" << *this << *an_issuer << an_issuer->getNotAfter();
+		qDebug() << "Possible Issuer of" << *this << *an_issuer << an_issuer->getNotAfter();
 		if (!an_issuer) {
 			qDebug("Certificate with id %d not found", q.value(0).toInt());
 			continue;
@@ -273,6 +277,100 @@ pki_x509 *pki_x509::getBySerial(const a1int &a) const
 	return NULL;
 }
 
+#define D5 "-----"
+#define OVPN_TA_KEY "OpenVPN Static key V1"
+
+QString pki_x509::getTaKey()
+{
+	XSqlQuery q;
+	QByteArray b;
+	pki_x509 *issuer = getSigner();
+	if (!isCA() && issuer && issuer != this)
+		return issuer->getTaKey();
+
+	Transaction;
+	if (!TransBegin())
+		return QString();
+
+	SQL_PREPARE(q, "SELECT value FROM takeys WHERE item = ?");
+	q.bindValue(0, sqlItemId);
+	q.exec();
+	if (q.next()) {
+		b = QByteArray::fromBase64(q.value(0).toByteArray());
+		qDebug() << "Loaded TA key" << this << b.size() << QString::fromLatin1(b.toHex()).left(6);
+	} else {
+		b.resize(2048/8);
+		RAND_bytes((unsigned char*)b.data(), 2048/8);
+		SQL_PREPARE(q, "INSERT INTO takeys (item, value) VALUES ( ?, ? )");
+		q.bindValue(0, sqlItemId);
+		q.bindValue(1, b.toBase64());
+		q.exec();
+		qDebug() << "Generated TA key" << this << b.size() << QString::fromLatin1(b.toHex()).left(6);
+	}
+	TransCommit();
+	QString takey(D5 "BEGIN " OVPN_TA_KEY D5 "\n");
+	QString hex(QString::fromLatin1(b.toHex()));
+	for (int i=0; i<16; i++)
+		takey += hex.mid(32*i, 32) + "\n";
+	takey += D5 "END " OVPN_TA_KEY D5 "\n";
+	return takey;
+}
+
+bool pki_x509::importTaKey(const QByteArray &takey)
+{
+	int start = takey.indexOf(D5 "BEGIN " OVPN_TA_KEY D5);
+	int end = takey.indexOf(D5 "END " OVPN_TA_KEY D5);
+	QByteArray data, existing_takey;
+	bool existed= false;
+
+	if (start >= 0 && end > 0 && start < end) {
+		start += sizeof D5 "BEGIN " OVPN_TA_KEY D5;
+		data = QByteArray::fromHex(takey.mid(start, end-start));
+		qDebug() << "TAKEY content" << start << end << data.size();
+	}
+	if (data.size() != 2048/8) {
+		XCA_ERROR(tr("Invalid OpenVPN tls-auth key"));
+		return false;
+	}
+
+	XSqlQuery q;
+	Transaction;
+	if (!TransBegin())
+		return false;
+
+	SQL_PREPARE(q, "SELECT value FROM takeys WHERE item = ?");
+	q.bindValue(0, sqlItemId);
+	q.exec();
+	if (q.next()) {
+		existed = true;
+		existing_takey = QByteArray::fromBase64(q.value(0).toByteArray());
+		qDebug() << "Existing TA key" << this << existing_takey.size()
+				<< QString::fromLatin1(existing_takey.toHex()).left(6);
+	}
+	if (existing_takey != data) {
+		if (existed)
+			SQL_PREPARE(q, "UPDATE takeys SET value = ? WHERE item = ?");
+		else
+			SQL_PREPARE(q, "INSERT INTO takeys (item, value) VALUES ( ?, ? )");
+		q.bindValue(0, sqlItemId);
+		q.bindValue(1, data.toBase64());
+		q.exec();
+	}
+	TransCommit();
+	QSqlError e = q.lastError();
+	if (e.isValid()) {
+		XCA_ERROR(tr("Failed to import tls-auth key"));
+		return false;
+	} else if (existing_takey == data) {
+		XCA_INFO(tr("Same tls-auth key already stored for this CA"));
+	} else if (existing_takey.isEmpty()) {
+		XCA_INFO(tr("New tls-auth key successfully imported"));
+	} else {
+		XCA_INFO(tr("Existing tls-auth key successfully replaced"));
+	}
+	return true;
+}
+
 a1int pki_x509::hashInfo(const EVP_MD *md) const
 {
 	unsigned char digest[EVP_MAX_MD_SIZE];
@@ -385,7 +483,7 @@ void pki_x509::store_token(bool alwaysSelect)
 		pk11_attr_data(CKA_LABEL, desc.toUtf8()) <<
 		(card ? card->getIdAttr() : p11.findUniqueID(CKO_CERTIFICATE));
 
-	if (p11.tokenLogin(p11.tokenInfo().label(), false).isNull())
+	if (!p11.tokenLoginForModification())
 		return;
 
 	p11.createObject(p11_atts);
@@ -440,7 +538,7 @@ void pki_x509::deleteFromToken(const slotid &slot)
 	{
 		return;
 	}
-	if (p11.tokenLogin(ti.label(), false).isNull())
+	if (!p11.tokenLoginForModification())
 		return;
 
 	p11.deleteObjects(objs);
@@ -458,8 +556,7 @@ int pki_x509::renameOnToken(const slotid &slot, const QString &name)
 		return 0;
 
 	pk11_attr_data label(CKA_LABEL, name.toUtf8());
-	tkInfo ti = p11.tokenInfo();
-	if (p11.tokenLogin(ti.label(), false).isNull())
+	if (!p11.tokenLoginForModification())
 		return 0;
 	p11.storeAttribute(label, objs[0]);
 	return 1;
@@ -538,15 +635,7 @@ void pki_x509::delSigner(pki_base *s)
 
 bool pki_x509::isCA() const
 {
-	bool ca;
-	int crit;
-	BASIC_CONSTRAINTS *bc = (BASIC_CONSTRAINTS *)
-		X509_get_ext_d2i(cert, NID_basic_constraints, &crit, NULL);
-	pki_openssl_error();
-	ca = bc && bc->ca;
-	if (bc)
-		BASIC_CONSTRAINTS_free(bc);
-	return ca;
+	return X509_check_ca(cert) == 1;
 }
 
 bool pki_x509::canSign() const
@@ -621,7 +710,48 @@ QString pki_x509::getIndexEntry()
 
 bool pki_x509::pem(BioByteArray &b)
 {
-	return PEM_write_bio_X509(b, cert);
+	const pki_export *xport = pki_export::by_id(Settings["CertFormat"]);
+
+	if (xport->match_all(F_PEM | F_CHAIN)) {
+		pki_x509 *iss, *prev;
+		for (iss = this, prev = nullptr; iss && iss != prev;
+			prev = iss, iss = iss->getSigner())
+		{
+			qDebug() << "Exporting to ClipBoard" << iss->getIntName();
+			if (!PEM_write_bio_X509(b, iss->cert))
+				return false;
+		}
+	} else if (xport->match_all(F_PEM | F_PRIVATE)) {
+		pki_key *key = getRefKey();
+		if (!key || !PEM_write_bio_X509(b, cert))
+			return false;
+		return key->pem(b, xport);
+	} else {
+		return PEM_write_bio_X509(b, cert);
+	}
+	return true;
+}
+
+void pki_x509::fillJWK(QJsonObject &json, const pki_export *xport) const
+{
+	QByteArray der = i2d();
+	pki_key *key = getPubKey();
+
+	key->fillJWK(json, xport);
+	json["kid"] = getIntName();
+	json["x5t"] = BioByteArray(Digest(der, EVP_sha1())).base64UrlEncode();
+	json["x5t#256"] = BioByteArray(Digest(der, EVP_sha256())).base64UrlEncode();
+	if (xport->match_all(F_JWK_X5C)) {
+		QJsonArray x5c;
+		for (const pki_x509 *cert = this, *prev = nullptr;
+			cert && cert != prev;
+			prev = cert, cert = cert->getSigner())
+		{
+			x5c.append(cert->i2d_b64());
+		}
+		json["x5c"] = x5c;
+	}
+	delete key;
 }
 
 bool pki_x509::cmpIssuerAndSerial(pki_x509 *refcert)
@@ -629,26 +759,11 @@ bool pki_x509::cmpIssuerAndSerial(pki_x509 *refcert)
 	bool ret =  X509_issuer_and_serial_cmp(cert, refcert->cert);
 	pki_openssl_error();
 	return ret;
-
 }
 
 bool pki_x509::verify_only(const pki_x509 *signer) const
 {
-	const X509_NAME *subject = X509_get_subject_name(signer->cert);
-	const X509_NAME *issuer = X509_get_issuer_name(cert);
-	pki_openssl_error();
-	if (X509_NAME_cmp(subject, issuer)) {
-		return false;
-	}
-	EVP_PKEY *pub = X509_get_pubkey(signer->cert);
-	if (!pub) {
-		pki_ign_openssl_error();
-		return false;
-	}
-	int i = X509_verify(cert, pub);
-	EVP_PKEY_free(pub);
-	pki_ign_openssl_error();
-	return i>0;
+	return X509_check_issued(signer->getCert(), cert) == X509_V_OK;
 }
 
 bool pki_x509::verify(pki_x509 *signer)
@@ -755,7 +870,7 @@ void pki_x509::setPubKey(pki_key *key)
 
 QString pki_x509::fingerprint(const EVP_MD *digest) const
 {
-	return ::fingerprint(i2d_bytearray(I2D_VOID(i2d_X509), cert), digest);
+	return ::fingerprint(i2d(), digest);
 }
 
 bool pki_x509::checkDate()
@@ -804,7 +919,7 @@ int pki_x509::sigAlg() const
 	return X509_get_signature_nid(cert);
 }
 
-pki_x509 *pki_x509::getSigner()
+pki_x509 *pki_x509::getSigner() const
 {
 	return Store.lookupPki<pki_x509>(issuerSqlId);
 }
@@ -977,6 +1092,11 @@ QVariant pki_x509::getIcon(const dbheader *hd) const
 	return QVariant(QPixmap(icon_names[pixnum]));
 }
 
+bool pki_x509::unusable() const
+{
+	return getNotAfter() < a1time::now() || isRevoked();
+}
+
 bool pki_x509::visible() const
 {
 	if (pki_x509super::visible())
@@ -1047,3 +1167,103 @@ QVariant pki_x509::bg_color(const dbheader *hd) const
 	}
 	return QVariant();
 }
+
+static int verify_cb(int ok, X509_STORE_CTX *ctx)
+{
+	int cert_error = X509_STORE_CTX_get_error(ctx);
+	QList<int> *errors = (QList<int>*)X509_STORE_CTX_get_app_data(ctx);
+
+	if (cert_error != X509_V_OK && errors->indexOf(cert_error) == -1)
+		errors->append(cert_error);
+
+	qDebug() << "OK:" << ok << "Error:" << cert_error
+		<< get_ossl_verify_error(cert_error);
+	return 1;
+}
+
+QList<int> pki_x509::ossl_verify() const
+{
+	STACK_OF(X509) *untrusted = sk_X509_new_null();
+	Q_CHECK_PTR(untrusted);
+	STACK_OF(X509) *trusted = sk_X509_new_null();
+	Q_CHECK_PTR(trusted);
+	X509_STORE_CTX *csc = X509_STORE_CTX_new();
+	Q_CHECK_PTR(csc);
+
+	for (pki_x509 *crt = getSigner(), *oldcrt = nullptr;
+		 crt && crt != oldcrt; oldcrt = crt, crt = crt->getSigner())
+	{
+		if (crt && crt == crt->getSigner())
+			sk_X509_push(trusted, crt->getCert());
+		else
+			sk_X509_push(untrusted, crt->getCert());
+	}
+	QList<int> errors;
+	X509_STORE_CTX_init(csc, NULL, cert, untrusted);
+	X509_STORE_CTX_set0_trusted_stack(csc, trusted);
+	X509_STORE_CTX_set_verify_cb(csc, verify_cb);
+	X509_STORE_CTX_set_app_data(csc, (void *)&errors);
+
+	X509_VERIFY_PARAM *param = X509_VERIFY_PARAM_new();
+	Q_CHECK_PTR(param);
+	X509_VERIFY_PARAM_set_flags(param, X509_V_FLAG_POLICY_CHECK | X509_V_FLAG_X509_STRICT);
+	X509_VERIFY_PARAM_set_depth(param, 20);
+	X509_STORE_CTX_set0_param(csc, param);
+
+	qDebug() << "########### START VERIFY" << getIntName();
+	int i = X509_verify_cert(csc);
+	for (int cert_error : errors) {
+		qDebug() << "VERIFY_CB" << getIntName() << cert_error
+			<< get_ossl_verify_error(cert_error)
+			<< X509_verify_cert_error_string(cert_error);
+	}
+	qDebug() << "########### END VERIFY" << getIntName() << i;
+
+	X509_STORE_CTX_free(csc);
+	sk_X509_free(untrusted);
+	sk_X509_free(trusted);
+
+	pki_ign_openssl_error();
+	return errors;
+}
+
+QList<X509_PURPOSE *> pki_x509::purposes() const
+{
+	QList<X509_PURPOSE *> purposes;
+	for (int i = 0; i< X509_PURPOSE_get_count(); i++) {
+		X509_PURPOSE *purp = X509_PURPOSE_get0(i);
+		int id = X509_PURPOSE_get_id(purp);
+		if (id == X509_PURPOSE_ANY)
+			continue;
+		Q_CHECK_PTR(purp);
+		int r = X509_check_purpose(cert, id, 0);
+		qDebug() << "Purpose" << i << X509_PURPOSE_get0_name(purp) << isCA() << r;
+		if (r)
+			purposes << purp;
+	}
+	return purposes;
+}
+
+int pki_x509::name_constraint_check(pki_x509 *issuer) const
+{
+	int rc = X509_V_OK;
+
+	if (!issuer || issuer == this)
+		return rc;
+
+	x509v3ext e = issuer->getExtByNid(NID_name_constraints);
+	if (e.nid() != NID_name_constraints)
+		return rc;
+
+	NAME_CONSTRAINTS *nc = (NAME_CONSTRAINTS *)e.d2i();
+	Q_CHECK_PTR(nc);
+	rc = NAME_CONSTRAINTS_check(cert, nc);
+#ifndef LIBRESSL_VERSION_NUMBER
+	if (!isCA() && rc == X509_V_OK)
+		rc = NAME_CONSTRAINTS_check_CN(cert, nc);
+#endif
+	NAME_CONSTRAINTS_free(nc);
+	pki_openssl_error();
+	qDebug() << getIntName() << issuer->getIntName() << get_ossl_verify_error(rc);
+	return rc;
+}
