@@ -80,12 +80,13 @@ class pki_x509 : public pki_x509super
 		bool isCA() const;
 		bool canSign() const;
 		void writeCert(XFile &file, bool PEM) const;
+		void fillJWK(QJsonObject &json, const pki_export *xport) const;
 		QString getIndexEntry();
 		bool verify(pki_x509 *signer);
 		bool verify_only(const pki_x509 *signer) const;
 		pki_key *getPubKey() const;
 		void setPubKey(pki_key *key);
-		pki_x509 *getSigner();
+		pki_x509 *getSigner() const;
 		void delSigner(pki_base *s);
 		QString fingerprint(const EVP_MD *digest) const;
 		extList getV3ext() const;
@@ -93,7 +94,7 @@ class pki_x509 : public pki_x509super
 		bool addV3ext(const x509v3ext &e, bool skip_existing = false);
 		void sign(pki_key *signkey, const digest &digest);
 		pki_x509 *findIssuer();
-		X509 *getCert()
+		X509 *getCert() const
 		{
 			return cert;
 		}
@@ -136,6 +137,7 @@ class pki_x509 : public pki_x509super
 		bool hasExtension(int nid) const;
 		bool cmpIssuerAndSerial(pki_x509 *refcert);
 		bool visible() const;
+		bool unusable() const;
 		void updateView();
 		void print(BioByteArray &b, enum print_opt opt) const;
 		x509v3ext getExtByNid(int nid) const;
@@ -146,7 +148,7 @@ class pki_x509 : public pki_x509super
 		void d2i(QByteArray &ba);
 		void deleteFromToken();
 		void deleteFromToken(const slotid &slot);
-		QString getMsg(msg_type msg) const;
+		QString getMsg(msg_type msg, int n = 1) const;
 		int renameOnToken(const slotid &slot, const QString &name);
 		bool pem(BioByteArray &);
 		QVariant bg_color(const dbheader *hd) const;
@@ -163,6 +165,12 @@ class pki_x509 : public pki_x509super
 		void restoreSql(const QSqlRecord &rec);
 		QStringList icsVEVENT() const;
 		QStringList icsVEVENT_ca() const;
+		QString getTaKey();
+		bool importTaKey(const QByteArray &takey);
+		QList<int> ossl_verify() const;
+		bool check_ca() const;
+		QList<X509_PURPOSE *> purposes() const;
+		int name_constraint_check(pki_x509 *issuer) const;
 };
 
 Q_DECLARE_METATYPE(pki_x509 *);
