@@ -19,8 +19,6 @@
 #include <QLineEdit>
 #include <QStringList>
 
-keyjob NewKey::defaultjob;
-
 class keyListItem
 {
     public:
@@ -86,7 +84,7 @@ class keyListItem
 Q_DECLARE_METATYPE(keyListItem);
 
 NewKey::NewKey(QWidget *parent, const QString &name)
-	:QDialog(parent ?: mainwin)
+	:QDialog(parent ? parent : mainwin)
 {
 	static const QList<int> sizeList = { 1024, 2048, 4096, 8192 };
 	slotidList p11_slots;
@@ -108,7 +106,7 @@ NewKey::NewKey(QWidget *parent, const QString &name)
 		keytypes << keyListItem(t);
 
 	updateCurves();
-	keyLength->setEditText(QString("%1 bit").arg(defaultjob.size));
+	keyLength->setEditText(QString("%1 bit").arg(keyjob::defaultjob.size));
 	keyDesc->setFocus();
 	if (pkcs11::libraries.loaded()) try {
 		pkcs11 p11;
@@ -119,9 +117,9 @@ NewKey::NewKey(QWidget *parent, const QString &name)
 			foreach(keytype t, keytype::types())
 				if (ml.contains(t.mech))
 					keytypes << keyListItem(&p11, slot,
-								t.type);
+								t.mech);
 		}
-	} catch (errorEx &err) {
+	} catch (errorEx &) {
 		p11_slots.clear();
 	}
 	for (int i=0; i<keytypes.count(); i++) {
@@ -129,7 +127,7 @@ NewKey::NewKey(QWidget *parent, const QString &name)
 		q.setValue(keytypes[i]);
 		keyType->addItem(keytypes[i].printname, q);
 		if (!keytypes[i].card &&
-		    keytypes[i].type() == defaultjob.ktype.type)
+		    keytypes[i].type() == keyjob::defaultjob.ktype.type)
 		{
 			keyType->setCurrentIndex(i);
 		}
@@ -175,7 +173,8 @@ void NewKey::updateCurves(unsigned min, unsigned max, unsigned long ec_flags)
 	curveBox->insertSeparator(curveBox->count());
 	addCurveBoxCurves(curve_other);
 
-	int default_index = curveBox->findData(QVariant(defaultjob.ec_nid));
+	int default_index = curveBox->findData(
+				QVariant(keyjob::defaultjob.ec_nid));
 	curveBox->setCurrentIndex(default_index == -1 ? 0 : default_index);
 #else
 	(void)min; (void)max; (void)ec_flags;
@@ -208,7 +207,7 @@ keyjob NewKey::getKeyJob() const
 		job.ec_nid = curveBox->itemData(idx).toInt();
 	} else {
 		QString size = keyLength->currentText();
-		size.replace(QRegExp("[^0-9]"), "");
+		size.replace(QRegularExpression("[^0-9]"), "");
 		job.size = size.toInt();
 	}
 	job.slot = selected.slot;
@@ -218,8 +217,8 @@ keyjob NewKey::getKeyJob() const
 void NewKey::accept()
 {
 	if (rememberDefault->isChecked()) {
-		defaultjob = getKeyJob();
-		Settings["defaultkey"] = defaultjob.toString();
+		keyjob::defaultjob = getKeyJob();
+		Settings["defaultkey"] = keyjob::defaultjob.toString();
 	}
 	QDialog::accept();
 }
