@@ -17,9 +17,9 @@ class PwDialog: public QDialog, public Ui::PwDialog
 	Q_OBJECT
 
    private:
-	bool wrDialog;
-	Passwd final;
-	pass_info *pi;
+	pass_info *pi{};
+	Passwd final{};
+	bool wrDialog{};
 
    public:
 	PwDialog(pass_info *p, bool write = false);
@@ -40,6 +40,6 @@ class PwDialog: public QDialog, public Ui::PwDialog
 class PwDialogUI: public PwDialogUI_i
 {
 	enum open_result execute(pass_info *p, Passwd *passwd,
-                        bool write = false, bool abort = false);
+	               bool write = false, bool abort = false);
 };
 #endif
