@@ -18,7 +18,7 @@ enum revCol { Cnumber, Cserial, Cdate, Creason, CiDate, Cmax };
 
 class revListItem : public QTreeWidgetItem
 {
-    public:
+  public:
 	revListItem(QTreeWidget *w) : QTreeWidgetItem(w) { };
 	bool operator < (const QTreeWidgetItem &other) const
 	{
@@ -95,7 +95,8 @@ void RevocationList::setupRevocationView(QTreeWidget *certList,
 	certList->setSelectionMode(QAbstractItemView::ExtendedSelection);
 }
 
-RevocationList::RevocationList(QWidget *w) : QDialog(w ? w : mainwin)
+RevocationList::RevocationList(QWidget *w)
+	: QDialog(w && w->isVisible() ? w : nullptr)
 {
 	QPushButton *genCrl;
 	setupUi(this);
@@ -130,7 +131,7 @@ const x509revList &RevocationList::getRevList()
 void RevocationList::on_addRev_clicked()
 {
 	Revocation *revoke = new Revocation(QModelIndexList(), this);
-        if (revoke->exec()) {
+	if (revoke->exec()) {
 		x509rev revit = revoke->getRevocation();
 		revList << revit;
 		addRevItem(certList, revit, revList.size(), issuer);
@@ -149,8 +150,8 @@ void RevocationList::on_delRev_clicked()
 	certList->takeTopLevelItem(idx);
 	rev.setSerial(a1int(current->text(Cserial)));
 	idx = revList.indexOf(rev);
-        if (idx != -1)
-                revList.takeAt(idx);
+	if (idx != -1)
+		revList.takeAt(idx);
 }
 
 void RevocationList::on_editRev_clicked()
@@ -168,14 +169,14 @@ void RevocationList::on_certList_itemDoubleClicked(QTreeWidgetItem *current)
 
 	rev.setSerial(a1int(current->text(Cserial)));
 	idx = revList.indexOf(rev);
-        if (idx == -1)
+	if (idx == -1)
 		return;
 
 	rev = revList[idx];
 
 	Revocation *revoke = new Revocation(QModelIndexList(), this);
 	revoke->setRevocation(rev);
-        if (revoke->exec()) {
+	if (revoke->exec()) {
 		a1time a1 = rev.getDate();
 		rev = revoke->getRevocation();
 		rev.setDate(a1);
