@@ -13,6 +13,7 @@
 #include <QRegularExpression>
 #include <QFileDialog>
 #include <QClipboard>
+#include <QActionGroup>
 
 #include "OidResolver.h"
 #include "XcaHeaderView.h"
@@ -25,6 +26,8 @@
 #include "ExportDialog.h"
 #include "ImportMulti.h"
 #include "lib/load_obj.h"
+#include "lib/pass_info.h"
+#include "lib/PwDialogCore.h"
 
 #include "ui_ItemProperties.h"
 
@@ -236,8 +239,7 @@ void XcaTreeView::deleteItems()
 {
 	QModelIndex index;
 	QModelIndexList indexes = getSelectedIndexes();
-	QString items, msg;
-	int count = 0;
+	QStringList items;
 	pki_base *pki = NULL;
 
 	if (indexes.count() == 0 || !basemodel)
@@ -245,21 +247,16 @@ void XcaTreeView::deleteItems()
 
 	foreach(index, indexes) {
 		pki = db_base::fromIndex(index);
-		items += "'" + pki->getIntName() + "' ";
-		count++;
+		if (pki)
+			items << pki->getIntName();
 	}
 
 	Transaction;
 	if (!TransBegin())
 		return;
 
-	if (count == 1)
-		msg = pki->getMsg(pki_base::msg_delete).arg(pki->getIntName());
-	else
-		msg = pki->getMsg(pki_base::msg_delete_multi).arg(count).
-				arg(items);
-
-	if (!XCA_OKCANCEL(msg))
+	if (!XCA_OKCANCEL(pki->getMsg(pki_base::msg_delete,
+			items.size()).arg(items.join("', '"))))
 		return;
 
 	foreach(index, indexes) {
@@ -479,24 +476,59 @@ void XcaTreeView::changeView()
 	show();
 }
 
+void XcaTreeView::exportItems(const QModelIndexList &indexes,
+	const QString &filename, const pki_export *xport)
+{
+	XFile file(filename);
+
+	if (xport->match_all(F_PRIVATE))
+		file.open_key();
+	else
+		file.open_write();
+
+	basemodel->exportItems(indexes, xport, file);
+}
+
 void XcaTreeView::exportItems(const QModelIndexList &indexes)
 {
 	if (!basemodel || indexes.empty())
 		return;
 
 	ExportDialog *dlg = exportDialog(indexes);
-
 	if (dlg && dlg->exec()) {
 		try {
+			QString fname = dlg->filename->text();
 			const pki_export *xport = dlg->export_type();
-			XFile file(dlg->filename->text());
 
-			if (xport->match_all(F_PRIVATE))
-				file.open_key();
-			else
-				file.open_write();
+			if (dlg->separateFiles->isChecked()) {
+				Passwd pass;
+				if (xport->match_all(F_CRYPT) && dlg->samePassword->isChecked())
+				{
+					// Plural form not required for < 2 items
+					// Will only be called for 2 or more items
+					pass_info p(tr("Export Password"),
+							tr("Please enter the password to encrypt all %n "
+							   "exported private key(s) in:\n%1",
+							   "Singular form for 0 or 1 item can be ignored. Will always be called with n >= 2",
+									indexes.size()).arg(fname),
+							this);
 
-			basemodel->exportItems(indexes, xport, file);
+					// Ask for an encryption password once
+					if (PwDialogCore::execute(&p, &pass, true) != 1)
+						return;
+				}
+				for (QModelIndex idx : indexes) {
+					pki_base *pki = db_base::fromIndex(idx);
+					// Will be cleared by PwDialogCore
+					PwDialogCore::cmdline_passwd = pass;
+					QString fn = pki->get_dump_filename(fname,
+							QString(".%1").arg(xport->extension));
+					exportItems(QModelIndexList() << idx, fn, xport);
+				}
+				PwDialogCore::cmdline_passwd.cleanse();
+			} else {
+				exportItems(indexes, fname, xport);
+			}
 		} catch (errorEx &err) {
 			XCA_ERROR(err);
 		}
@@ -531,12 +563,19 @@ void XcaTreeView::showContextMenu(QContextMenuEvent *e,
 		menu->addAction(tr("Delete"), this, SLOT(deleteItems()))->
 				setShortcut(QKeySequence::Delete);
 		subExport = menu->addMenu(tr("Export"));
-		subExport->addAction(tr("Clipboard"), this,
+		const pki_export *xport = pki_export::by_id(Settings[ClipboardSettings]);
+		QString clipboard = tr("Clipboard");
+		if (xport)
+			clipboard = QString("%1 (%2)").arg(clipboard).arg(xport->desc);
+
+		subExport->addAction(clipboard, this,
 				SLOT(pem2clipboard()))->setShortcut(QKeySequence::Copy);
 		subExport->addAction(tr("File"), this, SLOT(exportItems()))->
 				setShortcut(QKeySequence::Save);
 	}
 
+	clipboardFormatMenu(menu);
+
 	fillContextMenu(menu, subExport, index, indexes);
 
 	contextMenu(e, menu, -1);
@@ -585,3 +624,31 @@ void XcaTreeView::changeEvent(QEvent *event)
 	}
     QTreeView::changeEvent(event);
 }
+
+void XcaTreeView::clipboardFormatMenu(QMenu *menu)
+{
+	if (!ClipboardSettings || !ClipboardPki_type)
+		return;
+	int exp_type = Settings[ClipboardSettings];
+
+	QActionGroup *group = new QActionGroup(menu);
+	QMenu *clipboard = menu->addMenu(tr("Clipboard format"));
+	foreach(const pki_export *x, pki_export::select(ClipboardPki_type, 0)) {
+		if (!(x->flags & F_CLIPBOARD))
+			continue;
+		QAction *a = clipboard->addAction(x->desc);
+		a->setData(x->id);
+		a->setCheckable(true);
+		a->setChecked(exp_type == x->id);
+		group->addAction(a);
+	}
+
+	connect(group, SIGNAL(triggered(QAction*)),
+		this, SLOT(clipboardFormat(QAction*)));
+}
+
+void XcaTreeView::clipboardFormat(QAction *a)
+{
+	if (ClipboardSettings)
+		Settings[ClipboardSettings] = a->data().toInt();
+}
